import React from "react";
import PropTypes from "prop-types";
import { Paper, Button } from "@mui/material";
import { makeStyles } from "@mui/material/styles";
import { useTranslation } from "react-i18next";
import { PaperTitle } from "components/common";
import { usePermissions } from "hooks";

const useStyles = makeStyles(theme => ({
  content: {
    "& > *": {
      margin: theme.spacing(1)
    }
  }
}));

const CacheSettingsComponent = ({ onResetCache }) => {
  const classes = useStyles();
  const { t } = useTranslation();
  const { sysAdmin } = usePermissions();

  return (
    <Paper variant="outlined">
      <PaperTitle text={t("Settings.Cache.Title")} />
      <div className={classes.content}>
        <Button variant="outlined" color="secondary" disabled={!sysAdmin} onClick={onResetCache}>
          {t("Settings.Cache.Reset")}
        </Button>
      </div>
    </Paper>
  );
};

CacheSettingsComponent.propTypes = {
  onResetCache: PropTypes.func.isRequired
};

export default CacheSettingsComponent;
